# Changelog

## [0.3.6a1](https://github.com/OpenVoiceOS/ovos-utils/tree/0.3.6a1) (2024-10-21)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-utils/compare/0.3.5...0.3.6a1)

**Merged pull requests:**

- Update ovos-workshop requirement from \<1.0.0,\>=0.0.13 to \>=0.0.13,\<2.0.0 in /requirements [\#289](https://github.com/OpenVoiceOS/ovos-utils/pull/289) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
